@@ -7,6 +7,7 @@ import httpx
 from ... import errors
 from ...client import AuthenticatedClient, Client
 from ...models.list_extended_jobs_response_200 import ListExtendedJobsResponse200
+from ...models.list_extended_jobs_trigger_kind import ListExtendedJobsTriggerKind
 from ...types import UNSET, Response, Unset
 
 
@@ -37,6 +38,7 @@ def _get_kwargs(
     allow_wildcards: Union[Unset, None, bool] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    trigger_kind: Union[Unset, None, ListExtendedJobsTriggerKind] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
@@ -119,6 +121,12 @@ def _get_kwargs(
 
     params["per_page"] = per_page
 
+    json_trigger_kind: Union[Unset, None, str] = UNSET
+    if not isinstance(trigger_kind, Unset):
+        json_trigger_kind = trigger_kind.value if trigger_kind else None
+
+    params["trigger_kind"] = json_trigger_kind
+
     params["is_skipped"] = is_skipped
 
     params["is_flow_step"] = is_flow_step
@@ -194,6 +202,7 @@ def sync_detailed(
     allow_wildcards: Union[Unset, None, bool] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    trigger_kind: Union[Unset, None, ListExtendedJobsTriggerKind] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
@@ -229,6 +238,7 @@ def sync_detailed(
         allow_wildcards (Union[Unset, None, bool]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
+        trigger_kind (Union[Unset, None, ListExtendedJobsTriggerKind]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
         has_null_parent (Union[Unset, None, bool]):
@@ -270,6 +280,7 @@ def sync_detailed(
         allow_wildcards=allow_wildcards,
         page=page,
         per_page=per_page,
+        trigger_kind=trigger_kind,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
         has_null_parent=has_null_parent,
@@ -313,6 +324,7 @@ def sync(
     allow_wildcards: Union[Unset, None, bool] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    trigger_kind: Union[Unset, None, ListExtendedJobsTriggerKind] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
@@ -348,6 +360,7 @@ def sync(
         allow_wildcards (Union[Unset, None, bool]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
+        trigger_kind (Union[Unset, None, ListExtendedJobsTriggerKind]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
         has_null_parent (Union[Unset, None, bool]):
@@ -390,6 +403,7 @@ def sync(
         allow_wildcards=allow_wildcards,
         page=page,
         per_page=per_page,
+        trigger_kind=trigger_kind,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
         has_null_parent=has_null_parent,
@@ -427,6 +441,7 @@ async def asyncio_detailed(
     allow_wildcards: Union[Unset, None, bool] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    trigger_kind: Union[Unset, None, ListExtendedJobsTriggerKind] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
@@ -462,6 +477,7 @@ async def asyncio_detailed(
         allow_wildcards (Union[Unset, None, bool]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
+        trigger_kind (Union[Unset, None, ListExtendedJobsTriggerKind]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
         has_null_parent (Union[Unset, None, bool]):
@@ -503,6 +519,7 @@ async def asyncio_detailed(
         allow_wildcards=allow_wildcards,
         page=page,
         per_page=per_page,
+        trigger_kind=trigger_kind,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
         has_null_parent=has_null_parent,
@@ -544,6 +561,7 @@ async def asyncio(
     allow_wildcards: Union[Unset, None, bool] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    trigger_kind: Union[Unset, None, ListExtendedJobsTriggerKind] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
@@ -579,6 +597,7 @@ async def asyncio(
         allow_wildcards (Union[Unset, None, bool]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
+        trigger_kind (Union[Unset, None, ListExtendedJobsTriggerKind]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
         has_null_parent (Union[Unset, None, bool]):
@@ -622,6 +641,7 @@ async def asyncio(
             allow_wildcards=allow_wildcards,
             page=page,
             per_page=per_page,
+            trigger_kind=trigger_kind,
             is_skipped=is_skipped,
             is_flow_step=is_flow_step,
             has_null_parent=has_null_parent,
