@@ -16,6 +16,12 @@ if TYPE_CHECKING:
     )
     from ..models.branch_all_branches_item_modules_item_stop_after_if import BranchAllBranchesItemModulesItemStopAfterIf
     from ..models.branch_all_branches_item_modules_item_suspend import BranchAllBranchesItemModulesItemSuspend
+    from ..models.branch_all_branches_item_modules_item_timeout_type_0 import (
+        BranchAllBranchesItemModulesItemTimeoutType0,
+    )
+    from ..models.branch_all_branches_item_modules_item_timeout_type_1 import (
+        BranchAllBranchesItemModulesItemTimeoutType1,
+    )
 
 
 T = TypeVar("T", bound="BranchAllBranchesItemModulesItem")
@@ -33,7 +39,8 @@ class BranchAllBranchesItemModulesItem:
         sleep (Union['BranchAllBranchesItemModulesItemSleepType0', 'BranchAllBranchesItemModulesItemSleepType1',
             Unset]):
         cache_ttl (Union[Unset, float]):
-        timeout (Union[Unset, float]):
+        timeout (Union['BranchAllBranchesItemModulesItemTimeoutType0', 'BranchAllBranchesItemModulesItemTimeoutType1',
+            Unset]):
         delete_after_use (Union[Unset, bool]):
         summary (Union[Unset, str]):
         mock (Union[Unset, BranchAllBranchesItemModulesItemMock]):
@@ -52,7 +59,9 @@ class BranchAllBranchesItemModulesItem:
         "BranchAllBranchesItemModulesItemSleepType0", "BranchAllBranchesItemModulesItemSleepType1", Unset
     ] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
-    timeout: Union[Unset, float] = UNSET
+    timeout: Union[
+        "BranchAllBranchesItemModulesItemTimeoutType0", "BranchAllBranchesItemModulesItemTimeoutType1", Unset
+    ] = UNSET
     delete_after_use: Union[Unset, bool] = UNSET
     summary: Union[Unset, str] = UNSET
     mock: Union[Unset, "BranchAllBranchesItemModulesItemMock"] = UNSET
@@ -66,6 +75,9 @@ class BranchAllBranchesItemModulesItem:
         from ..models.branch_all_branches_item_modules_item_sleep_type_0 import (
             BranchAllBranchesItemModulesItemSleepType0,
         )
+        from ..models.branch_all_branches_item_modules_item_timeout_type_0 import (
+            BranchAllBranchesItemModulesItemTimeoutType0,
+        )
 
         id = self.id
         value = self.value
@@ -96,7 +108,20 @@ class BranchAllBranchesItemModulesItem:
                 sleep = self.sleep.to_dict()
 
         cache_ttl = self.cache_ttl
-        timeout = self.timeout
+        timeout: Union[Dict[str, Any], Unset]
+        if isinstance(self.timeout, Unset):
+            timeout = UNSET
+
+        elif isinstance(self.timeout, BranchAllBranchesItemModulesItemTimeoutType0):
+            timeout = UNSET
+            if not isinstance(self.timeout, Unset):
+                timeout = self.timeout.to_dict()
+
+        else:
+            timeout = UNSET
+            if not isinstance(self.timeout, Unset):
+                timeout = self.timeout.to_dict()
+
         delete_after_use = self.delete_after_use
         summary = self.summary
         mock: Union[Unset, Dict[str, Any]] = UNSET
@@ -168,6 +193,12 @@ class BranchAllBranchesItemModulesItem:
             BranchAllBranchesItemModulesItemStopAfterIf,
         )
         from ..models.branch_all_branches_item_modules_item_suspend import BranchAllBranchesItemModulesItemSuspend
+        from ..models.branch_all_branches_item_modules_item_timeout_type_0 import (
+            BranchAllBranchesItemModulesItemTimeoutType0,
+        )
+        from ..models.branch_all_branches_item_modules_item_timeout_type_1 import (
+            BranchAllBranchesItemModulesItemTimeoutType1,
+        )
 
         d = src_dict.copy()
         id = d.pop("id")
@@ -230,7 +261,38 @@ class BranchAllBranchesItemModulesItem:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
-        timeout = d.pop("timeout", UNSET)
+        def _parse_timeout(
+            data: object,
+        ) -> Union[
+            "BranchAllBranchesItemModulesItemTimeoutType0", "BranchAllBranchesItemModulesItemTimeoutType1", Unset
+        ]:
+            if isinstance(data, Unset):
+                return data
+            try:
+                if not isinstance(data, dict):
+                    raise TypeError()
+                _timeout_type_0 = data
+                timeout_type_0: Union[Unset, BranchAllBranchesItemModulesItemTimeoutType0]
+                if isinstance(_timeout_type_0, Unset):
+                    timeout_type_0 = UNSET
+                else:
+                    timeout_type_0 = BranchAllBranchesItemModulesItemTimeoutType0.from_dict(_timeout_type_0)
+
+                return timeout_type_0
+            except:  # noqa: E722
+                pass
+            if not isinstance(data, dict):
+                raise TypeError()
+            _timeout_type_1 = data
+            timeout_type_1: Union[Unset, BranchAllBranchesItemModulesItemTimeoutType1]
+            if isinstance(_timeout_type_1, Unset):
+                timeout_type_1 = UNSET
+            else:
+                timeout_type_1 = BranchAllBranchesItemModulesItemTimeoutType1.from_dict(_timeout_type_1)
+
+            return timeout_type_1
+
+        timeout = _parse_timeout(d.pop("timeout", UNSET))
 
         delete_after_use = d.pop("delete_after_use", UNSET)
 
