@@ -36,6 +36,7 @@ class CreateHttpTriggerJsonBody:
         is_async (Union[Unset, bool]): Deprecated, use request_type instead
         request_type (Union[Unset, CreateHttpTriggerJsonBodyRequestType]):
         wrap_body (Union[Unset, bool]):
+        enabled (Union[Unset, bool]):
         raw_string (Union[Unset, bool]):
         error_handler_path (Union[Unset, str]):
         error_handler_args (Union[Unset, CreateHttpTriggerJsonBodyErrorHandlerArgs]): The arguments to pass to the
@@ -58,6 +59,7 @@ class CreateHttpTriggerJsonBody:
     is_async: Union[Unset, bool] = UNSET
     request_type: Union[Unset, CreateHttpTriggerJsonBodyRequestType] = UNSET
     wrap_body: Union[Unset, bool] = UNSET
+    enabled: Union[Unset, bool] = UNSET
     raw_string: Union[Unset, bool] = UNSET
     error_handler_path: Union[Unset, str] = UNSET
     error_handler_args: Union[Unset, "CreateHttpTriggerJsonBodyErrorHandlerArgs"] = UNSET
@@ -88,6 +90,7 @@ class CreateHttpTriggerJsonBody:
             request_type = self.request_type.value
 
         wrap_body = self.wrap_body
+        enabled = self.enabled
         raw_string = self.raw_string
         error_handler_path = self.error_handler_path
         error_handler_args: Union[Unset, Dict[str, Any]] = UNSET
@@ -127,6 +130,8 @@ class CreateHttpTriggerJsonBody:
             field_dict["request_type"] = request_type
         if wrap_body is not UNSET:
             field_dict["wrap_body"] = wrap_body
+        if enabled is not UNSET:
+            field_dict["enabled"] = enabled
         if raw_string is not UNSET:
             field_dict["raw_string"] = raw_string
         if error_handler_path is not UNSET:
@@ -187,6 +192,8 @@ class CreateHttpTriggerJsonBody:
 
         wrap_body = d.pop("wrap_body", UNSET)
 
+        enabled = d.pop("enabled", UNSET)
+
         raw_string = d.pop("raw_string", UNSET)
 
         error_handler_path = d.pop("error_handler_path", UNSET)
@@ -221,6 +228,7 @@ class CreateHttpTriggerJsonBody:
             is_async=is_async,
             request_type=request_type,
             wrap_body=wrap_body,
+            enabled=enabled,
             raw_string=raw_string,
             error_handler_path=error_handler_path,
             error_handler_args=error_handler_args,
