@@ -42,6 +42,7 @@ class CreateHttpTriggersJsonBodyItem:
         is_async (Union[Unset, bool]): Deprecated, use request_type instead
         request_type (Union[Unset, CreateHttpTriggersJsonBodyItemRequestType]):
         wrap_body (Union[Unset, bool]):
+        enabled (Union[Unset, bool]):
         raw_string (Union[Unset, bool]):
         error_handler_path (Union[Unset, str]):
         error_handler_args (Union[Unset, CreateHttpTriggersJsonBodyItemErrorHandlerArgs]): The arguments to pass to the
@@ -64,6 +65,7 @@ class CreateHttpTriggersJsonBodyItem:
     is_async: Union[Unset, bool] = UNSET
     request_type: Union[Unset, CreateHttpTriggersJsonBodyItemRequestType] = UNSET
     wrap_body: Union[Unset, bool] = UNSET
+    enabled: Union[Unset, bool] = UNSET
     raw_string: Union[Unset, bool] = UNSET
     error_handler_path: Union[Unset, str] = UNSET
     error_handler_args: Union[Unset, "CreateHttpTriggersJsonBodyItemErrorHandlerArgs"] = UNSET
@@ -94,6 +96,7 @@ class CreateHttpTriggersJsonBodyItem:
             request_type = self.request_type.value
 
         wrap_body = self.wrap_body
+        enabled = self.enabled
         raw_string = self.raw_string
         error_handler_path = self.error_handler_path
         error_handler_args: Union[Unset, Dict[str, Any]] = UNSET
@@ -133,6 +136,8 @@ class CreateHttpTriggersJsonBodyItem:
             field_dict["request_type"] = request_type
         if wrap_body is not UNSET:
             field_dict["wrap_body"] = wrap_body
+        if enabled is not UNSET:
+            field_dict["enabled"] = enabled
         if raw_string is not UNSET:
             field_dict["raw_string"] = raw_string
         if error_handler_path is not UNSET:
@@ -195,6 +200,8 @@ class CreateHttpTriggersJsonBodyItem:
 
         wrap_body = d.pop("wrap_body", UNSET)
 
+        enabled = d.pop("enabled", UNSET)
+
         raw_string = d.pop("raw_string", UNSET)
 
         error_handler_path = d.pop("error_handler_path", UNSET)
@@ -229,6 +236,7 @@ class CreateHttpTriggersJsonBodyItem:
             is_async=is_async,
             request_type=request_type,
             wrap_body=wrap_body,
+            enabled=enabled,
             raw_string=raw_string,
             error_handler_path=error_handler_path,
             error_handler_args=error_handler_args,
