@@ -8,6 +8,7 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.edit_schedule_retry_constant import EditScheduleRetryConstant
     from ..models.edit_schedule_retry_exponential import EditScheduleRetryExponential
+    from ..models.edit_schedule_retry_retry_if import EditScheduleRetryRetryIf
 
 
 T = TypeVar("T", bound="EditScheduleRetry")
@@ -20,10 +21,12 @@ class EditScheduleRetry:
     Attributes:
         constant (Union[Unset, EditScheduleRetryConstant]):
         exponential (Union[Unset, EditScheduleRetryExponential]):
+        retry_if (Union[Unset, EditScheduleRetryRetryIf]):
     """
 
     constant: Union[Unset, "EditScheduleRetryConstant"] = UNSET
     exponential: Union[Unset, "EditScheduleRetryExponential"] = UNSET
+    retry_if: Union[Unset, "EditScheduleRetryRetryIf"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -35,6 +38,10 @@ class EditScheduleRetry:
         if not isinstance(self.exponential, Unset):
             exponential = self.exponential.to_dict()
 
+        retry_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry_if, Unset):
+            retry_if = self.retry_if.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
@@ -42,6 +49,8 @@ class EditScheduleRetry:
             field_dict["constant"] = constant
         if exponential is not UNSET:
             field_dict["exponential"] = exponential
+        if retry_if is not UNSET:
+            field_dict["retry_if"] = retry_if
 
         return field_dict
 
@@ -49,6 +58,7 @@ class EditScheduleRetry:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.edit_schedule_retry_constant import EditScheduleRetryConstant
         from ..models.edit_schedule_retry_exponential import EditScheduleRetryExponential
+        from ..models.edit_schedule_retry_retry_if import EditScheduleRetryRetryIf
 
         d = src_dict.copy()
         _constant = d.pop("constant", UNSET)
@@ -65,9 +75,17 @@ class EditScheduleRetry:
         else:
             exponential = EditScheduleRetryExponential.from_dict(_exponential)
 
+        _retry_if = d.pop("retry_if", UNSET)
+        retry_if: Union[Unset, EditScheduleRetryRetryIf]
+        if isinstance(_retry_if, Unset):
+            retry_if = UNSET
+        else:
+            retry_if = EditScheduleRetryRetryIf.from_dict(_retry_if)
+
         edit_schedule_retry = cls(
             constant=constant,
             exponential=exponential,
+            retry_if=retry_if,
         )
 
         edit_schedule_retry.additional_properties = d
