@@ -13,6 +13,7 @@ if TYPE_CHECKING:
     from ..models.extended_jobs_jobs_item_type_0_raw_flow_modules_item import (
         ExtendedJobsJobsItemType0RawFlowModulesItem,
     )
+    from ..models.extended_jobs_jobs_item_type_0_raw_flow_notes_item import ExtendedJobsJobsItemType0RawFlowNotesItem
     from ..models.extended_jobs_jobs_item_type_0_raw_flow_preprocessor_module import (
         ExtendedJobsJobsItemType0RawFlowPreprocessorModule,
     )
@@ -40,6 +41,7 @@ class ExtendedJobsJobsItemType0RawFlow:
         priority (Union[Unset, float]):
         early_return (Union[Unset, str]):
         chat_input_enabled (Union[Unset, bool]): Whether this flow accepts chat-style input
+        notes (Union[Unset, List['ExtendedJobsJobsItemType0RawFlowNotesItem']]): Sticky notes attached to the flow
     """
 
     modules: List["ExtendedJobsJobsItemType0RawFlowModulesItem"]
@@ -57,6 +59,7 @@ class ExtendedJobsJobsItemType0RawFlow:
     priority: Union[Unset, float] = UNSET
     early_return: Union[Unset, str] = UNSET
     chat_input_enabled: Union[Unset, bool] = UNSET
+    notes: Union[Unset, List["ExtendedJobsJobsItemType0RawFlowNotesItem"]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -89,6 +92,13 @@ class ExtendedJobsJobsItemType0RawFlow:
         priority = self.priority
         early_return = self.early_return
         chat_input_enabled = self.chat_input_enabled
+        notes: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.notes, Unset):
+            notes = []
+            for notes_item_data in self.notes:
+                notes_item = notes_item_data.to_dict()
+
+                notes.append(notes_item)
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -125,6 +135,8 @@ class ExtendedJobsJobsItemType0RawFlow:
             field_dict["early_return"] = early_return
         if chat_input_enabled is not UNSET:
             field_dict["chat_input_enabled"] = chat_input_enabled
+        if notes is not UNSET:
+            field_dict["notes"] = notes
 
         return field_dict
 
@@ -137,6 +149,9 @@ class ExtendedJobsJobsItemType0RawFlow:
         from ..models.extended_jobs_jobs_item_type_0_raw_flow_modules_item import (
             ExtendedJobsJobsItemType0RawFlowModulesItem,
         )
+        from ..models.extended_jobs_jobs_item_type_0_raw_flow_notes_item import (
+            ExtendedJobsJobsItemType0RawFlowNotesItem,
+        )
         from ..models.extended_jobs_jobs_item_type_0_raw_flow_preprocessor_module import (
             ExtendedJobsJobsItemType0RawFlowPreprocessorModule,
         )
@@ -192,6 +207,13 @@ class ExtendedJobsJobsItemType0RawFlow:
 
         chat_input_enabled = d.pop("chat_input_enabled", UNSET)
 
+        notes = []
+        _notes = d.pop("notes", UNSET)
+        for notes_item_data in _notes or []:
+            notes_item = ExtendedJobsJobsItemType0RawFlowNotesItem.from_dict(notes_item_data)
+
+            notes.append(notes_item)
+
         extended_jobs_jobs_item_type_0_raw_flow = cls(
             modules=modules,
             failure_module=failure_module,
@@ -208,6 +230,7 @@ class ExtendedJobsJobsItemType0RawFlow:
             priority=priority,
             early_return=early_return,
             chat_input_enabled=chat_input_enabled,
+            notes=notes,
         )
 
         extended_jobs_jobs_item_type_0_raw_flow.additional_properties = d
