@@ -9,6 +9,7 @@ if TYPE_CHECKING:
     from ..models.get_flow_by_path_response_200_value_failure_module import GetFlowByPathResponse200ValueFailureModule
     from ..models.get_flow_by_path_response_200_value_flow_env import GetFlowByPathResponse200ValueFlowEnv
     from ..models.get_flow_by_path_response_200_value_modules_item import GetFlowByPathResponse200ValueModulesItem
+    from ..models.get_flow_by_path_response_200_value_notes_item import GetFlowByPathResponse200ValueNotesItem
     from ..models.get_flow_by_path_response_200_value_preprocessor_module import (
         GetFlowByPathResponse200ValuePreprocessorModule,
     )
@@ -36,6 +37,7 @@ class GetFlowByPathResponse200Value:
         priority (Union[Unset, float]):
         early_return (Union[Unset, str]):
         chat_input_enabled (Union[Unset, bool]): Whether this flow accepts chat-style input
+        notes (Union[Unset, List['GetFlowByPathResponse200ValueNotesItem']]): Sticky notes attached to the flow
     """
 
     modules: List["GetFlowByPathResponse200ValueModulesItem"]
@@ -53,6 +55,7 @@ class GetFlowByPathResponse200Value:
     priority: Union[Unset, float] = UNSET
     early_return: Union[Unset, str] = UNSET
     chat_input_enabled: Union[Unset, bool] = UNSET
+    notes: Union[Unset, List["GetFlowByPathResponse200ValueNotesItem"]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -85,6 +88,13 @@ class GetFlowByPathResponse200Value:
         priority = self.priority
         early_return = self.early_return
         chat_input_enabled = self.chat_input_enabled
+        notes: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.notes, Unset):
+            notes = []
+            for notes_item_data in self.notes:
+                notes_item = notes_item_data.to_dict()
+
+                notes.append(notes_item)
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -121,6 +131,8 @@ class GetFlowByPathResponse200Value:
             field_dict["early_return"] = early_return
         if chat_input_enabled is not UNSET:
             field_dict["chat_input_enabled"] = chat_input_enabled
+        if notes is not UNSET:
+            field_dict["notes"] = notes
 
         return field_dict
 
@@ -131,6 +143,7 @@ class GetFlowByPathResponse200Value:
         )
         from ..models.get_flow_by_path_response_200_value_flow_env import GetFlowByPathResponse200ValueFlowEnv
         from ..models.get_flow_by_path_response_200_value_modules_item import GetFlowByPathResponse200ValueModulesItem
+        from ..models.get_flow_by_path_response_200_value_notes_item import GetFlowByPathResponse200ValueNotesItem
         from ..models.get_flow_by_path_response_200_value_preprocessor_module import (
             GetFlowByPathResponse200ValuePreprocessorModule,
         )
@@ -186,6 +199,13 @@ class GetFlowByPathResponse200Value:
 
         chat_input_enabled = d.pop("chat_input_enabled", UNSET)
 
+        notes = []
+        _notes = d.pop("notes", UNSET)
+        for notes_item_data in _notes or []:
+            notes_item = GetFlowByPathResponse200ValueNotesItem.from_dict(notes_item_data)
+
+            notes.append(notes_item)
+
         get_flow_by_path_response_200_value = cls(
             modules=modules,
             failure_module=failure_module,
@@ -202,6 +222,7 @@ class GetFlowByPathResponse200Value:
             priority=priority,
             early_return=early_return,
             chat_input_enabled=chat_input_enabled,
+            notes=notes,
         )
 
         get_flow_by_path_response_200_value.additional_properties = d
