@@ -9,6 +9,7 @@ if TYPE_CHECKING:
     from ..models.get_job_response_200_type_0_raw_flow_failure_module import GetJobResponse200Type0RawFlowFailureModule
     from ..models.get_job_response_200_type_0_raw_flow_flow_env import GetJobResponse200Type0RawFlowFlowEnv
     from ..models.get_job_response_200_type_0_raw_flow_modules_item import GetJobResponse200Type0RawFlowModulesItem
+    from ..models.get_job_response_200_type_0_raw_flow_notes_item import GetJobResponse200Type0RawFlowNotesItem
     from ..models.get_job_response_200_type_0_raw_flow_preprocessor_module import (
         GetJobResponse200Type0RawFlowPreprocessorModule,
     )
@@ -36,6 +37,7 @@ class GetJobResponse200Type0RawFlow:
         priority (Union[Unset, float]):
         early_return (Union[Unset, str]):
         chat_input_enabled (Union[Unset, bool]): Whether this flow accepts chat-style input
+        notes (Union[Unset, List['GetJobResponse200Type0RawFlowNotesItem']]): Sticky notes attached to the flow
     """
 
     modules: List["GetJobResponse200Type0RawFlowModulesItem"]
@@ -53,6 +55,7 @@ class GetJobResponse200Type0RawFlow:
     priority: Union[Unset, float] = UNSET
     early_return: Union[Unset, str] = UNSET
     chat_input_enabled: Union[Unset, bool] = UNSET
+    notes: Union[Unset, List["GetJobResponse200Type0RawFlowNotesItem"]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -85,6 +88,13 @@ class GetJobResponse200Type0RawFlow:
         priority = self.priority
         early_return = self.early_return
         chat_input_enabled = self.chat_input_enabled
+        notes: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.notes, Unset):
+            notes = []
+            for notes_item_data in self.notes:
+                notes_item = notes_item_data.to_dict()
+
+                notes.append(notes_item)
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -121,6 +131,8 @@ class GetJobResponse200Type0RawFlow:
             field_dict["early_return"] = early_return
         if chat_input_enabled is not UNSET:
             field_dict["chat_input_enabled"] = chat_input_enabled
+        if notes is not UNSET:
+            field_dict["notes"] = notes
 
         return field_dict
 
@@ -131,6 +143,7 @@ class GetJobResponse200Type0RawFlow:
         )
         from ..models.get_job_response_200_type_0_raw_flow_flow_env import GetJobResponse200Type0RawFlowFlowEnv
         from ..models.get_job_response_200_type_0_raw_flow_modules_item import GetJobResponse200Type0RawFlowModulesItem
+        from ..models.get_job_response_200_type_0_raw_flow_notes_item import GetJobResponse200Type0RawFlowNotesItem
         from ..models.get_job_response_200_type_0_raw_flow_preprocessor_module import (
             GetJobResponse200Type0RawFlowPreprocessorModule,
         )
@@ -186,6 +199,13 @@ class GetJobResponse200Type0RawFlow:
 
         chat_input_enabled = d.pop("chat_input_enabled", UNSET)
 
+        notes = []
+        _notes = d.pop("notes", UNSET)
+        for notes_item_data in _notes or []:
+            notes_item = GetJobResponse200Type0RawFlowNotesItem.from_dict(notes_item_data)
+
+            notes.append(notes_item)
+
         get_job_response_200_type_0_raw_flow = cls(
             modules=modules,
             failure_module=failure_module,
@@ -202,6 +222,7 @@ class GetJobResponse200Type0RawFlow:
             priority=priority,
             early_return=early_return,
             chat_input_enabled=chat_input_enabled,
+            notes=notes,
         )
 
         get_job_response_200_type_0_raw_flow.additional_properties = d
