@@ -46,6 +46,7 @@ class ListHttpTriggersResponse200Item:
         edited_by (str):
         edited_at (datetime.datetime):
         is_flow (bool):
+        enabled (bool):
         static_asset_config (Union[Unset, ListHttpTriggersResponse200ItemStaticAssetConfig]):
         authentication_resource_path (Union[Unset, str]):
         summary (Union[Unset, str]):
@@ -72,6 +73,7 @@ class ListHttpTriggersResponse200Item:
     edited_by: str
     edited_at: datetime.datetime
     is_flow: bool
+    enabled: bool
     static_asset_config: Union[Unset, "ListHttpTriggersResponse200ItemStaticAssetConfig"] = UNSET
     authentication_resource_path: Union[Unset, str] = UNSET
     summary: Union[Unset, str] = UNSET
@@ -103,6 +105,7 @@ class ListHttpTriggersResponse200Item:
         edited_at = self.edited_at.isoformat()
 
         is_flow = self.is_flow
+        enabled = self.enabled
         static_asset_config: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.static_asset_config, Unset):
             static_asset_config = self.static_asset_config.to_dict()
@@ -139,6 +142,7 @@ class ListHttpTriggersResponse200Item:
                 "edited_by": edited_by,
                 "edited_at": edited_at,
                 "is_flow": is_flow,
+                "enabled": enabled,
             }
         )
         if static_asset_config is not UNSET:
@@ -202,6 +206,8 @@ class ListHttpTriggersResponse200Item:
 
         is_flow = d.pop("is_flow")
 
+        enabled = d.pop("enabled")
+
         _static_asset_config = d.pop("static_asset_config", UNSET)
         static_asset_config: Union[Unset, ListHttpTriggersResponse200ItemStaticAssetConfig]
         if isinstance(_static_asset_config, Unset):
@@ -248,6 +254,7 @@ class ListHttpTriggersResponse200Item:
             edited_by=edited_by,
             edited_at=edited_at,
             is_flow=is_flow,
+            enabled=enabled,
             static_asset_config=static_asset_config,
             authentication_resource_path=authentication_resource_path,
             summary=summary,
