@@ -13,6 +13,9 @@ if TYPE_CHECKING:
     from ..models.list_jobs_response_200_item_type_0_raw_flow_modules_item import (
         ListJobsResponse200ItemType0RawFlowModulesItem,
     )
+    from ..models.list_jobs_response_200_item_type_0_raw_flow_notes_item import (
+        ListJobsResponse200ItemType0RawFlowNotesItem,
+    )
     from ..models.list_jobs_response_200_item_type_0_raw_flow_preprocessor_module import (
         ListJobsResponse200ItemType0RawFlowPreprocessorModule,
     )
@@ -40,6 +43,7 @@ class ListJobsResponse200ItemType0RawFlow:
         priority (Union[Unset, float]):
         early_return (Union[Unset, str]):
         chat_input_enabled (Union[Unset, bool]): Whether this flow accepts chat-style input
+        notes (Union[Unset, List['ListJobsResponse200ItemType0RawFlowNotesItem']]): Sticky notes attached to the flow
     """
 
     modules: List["ListJobsResponse200ItemType0RawFlowModulesItem"]
@@ -57,6 +61,7 @@ class ListJobsResponse200ItemType0RawFlow:
     priority: Union[Unset, float] = UNSET
     early_return: Union[Unset, str] = UNSET
     chat_input_enabled: Union[Unset, bool] = UNSET
+    notes: Union[Unset, List["ListJobsResponse200ItemType0RawFlowNotesItem"]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -89,6 +94,13 @@ class ListJobsResponse200ItemType0RawFlow:
         priority = self.priority
         early_return = self.early_return
         chat_input_enabled = self.chat_input_enabled
+        notes: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.notes, Unset):
+            notes = []
+            for notes_item_data in self.notes:
+                notes_item = notes_item_data.to_dict()
+
+                notes.append(notes_item)
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -125,6 +137,8 @@ class ListJobsResponse200ItemType0RawFlow:
             field_dict["early_return"] = early_return
         if chat_input_enabled is not UNSET:
             field_dict["chat_input_enabled"] = chat_input_enabled
+        if notes is not UNSET:
+            field_dict["notes"] = notes
 
         return field_dict
 
@@ -139,6 +153,9 @@ class ListJobsResponse200ItemType0RawFlow:
         from ..models.list_jobs_response_200_item_type_0_raw_flow_modules_item import (
             ListJobsResponse200ItemType0RawFlowModulesItem,
         )
+        from ..models.list_jobs_response_200_item_type_0_raw_flow_notes_item import (
+            ListJobsResponse200ItemType0RawFlowNotesItem,
+        )
         from ..models.list_jobs_response_200_item_type_0_raw_flow_preprocessor_module import (
             ListJobsResponse200ItemType0RawFlowPreprocessorModule,
         )
@@ -194,6 +211,13 @@ class ListJobsResponse200ItemType0RawFlow:
 
         chat_input_enabled = d.pop("chat_input_enabled", UNSET)
 
+        notes = []
+        _notes = d.pop("notes", UNSET)
+        for notes_item_data in _notes or []:
+            notes_item = ListJobsResponse200ItemType0RawFlowNotesItem.from_dict(notes_item_data)
+
+            notes.append(notes_item)
+
         list_jobs_response_200_item_type_0_raw_flow = cls(
             modules=modules,
             failure_module=failure_module,
@@ -210,6 +234,7 @@ class ListJobsResponse200ItemType0RawFlow:
             priority=priority,
             early_return=early_return,
             chat_input_enabled=chat_input_enabled,
+            notes=notes,
         )
 
         list_jobs_response_200_item_type_0_raw_flow.additional_properties = d
