@@ -9,6 +9,7 @@ if TYPE_CHECKING:
     from ..models.open_flow_value_failure_module import OpenFlowValueFailureModule
     from ..models.open_flow_value_flow_env import OpenFlowValueFlowEnv
     from ..models.open_flow_value_modules_item import OpenFlowValueModulesItem
+    from ..models.open_flow_value_notes_item import OpenFlowValueNotesItem
     from ..models.open_flow_value_preprocessor_module import OpenFlowValuePreprocessorModule
 
 
@@ -34,6 +35,7 @@ class OpenFlowValue:
         priority (Union[Unset, float]):
         early_return (Union[Unset, str]):
         chat_input_enabled (Union[Unset, bool]): Whether this flow accepts chat-style input
+        notes (Union[Unset, List['OpenFlowValueNotesItem']]): Sticky notes attached to the flow
     """
 
     modules: List["OpenFlowValueModulesItem"]
@@ -51,6 +53,7 @@ class OpenFlowValue:
     priority: Union[Unset, float] = UNSET
     early_return: Union[Unset, str] = UNSET
     chat_input_enabled: Union[Unset, bool] = UNSET
+    notes: Union[Unset, List["OpenFlowValueNotesItem"]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -83,6 +86,13 @@ class OpenFlowValue:
         priority = self.priority
         early_return = self.early_return
         chat_input_enabled = self.chat_input_enabled
+        notes: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.notes, Unset):
+            notes = []
+            for notes_item_data in self.notes:
+                notes_item = notes_item_data.to_dict()
+
+                notes.append(notes_item)
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -119,6 +129,8 @@ class OpenFlowValue:
             field_dict["early_return"] = early_return
         if chat_input_enabled is not UNSET:
             field_dict["chat_input_enabled"] = chat_input_enabled
+        if notes is not UNSET:
+            field_dict["notes"] = notes
 
         return field_dict
 
@@ -127,6 +139,7 @@ class OpenFlowValue:
         from ..models.open_flow_value_failure_module import OpenFlowValueFailureModule
         from ..models.open_flow_value_flow_env import OpenFlowValueFlowEnv
         from ..models.open_flow_value_modules_item import OpenFlowValueModulesItem
+        from ..models.open_flow_value_notes_item import OpenFlowValueNotesItem
         from ..models.open_flow_value_preprocessor_module import OpenFlowValuePreprocessorModule
 
         d = src_dict.copy()
@@ -180,6 +193,13 @@ class OpenFlowValue:
 
         chat_input_enabled = d.pop("chat_input_enabled", UNSET)
 
+        notes = []
+        _notes = d.pop("notes", UNSET)
+        for notes_item_data in _notes or []:
+            notes_item = OpenFlowValueNotesItem.from_dict(notes_item_data)
+
+            notes.append(notes_item)
+
         open_flow_value = cls(
             modules=modules,
             failure_module=failure_module,
@@ -196,6 +216,7 @@ class OpenFlowValue:
             priority=priority,
             early_return=early_return,
             chat_input_enabled=chat_input_enabled,
+            notes=notes,
         )
 
         open_flow_value.additional_properties = d
