@@ -16,6 +16,8 @@ if TYPE_CHECKING:
     )
     from ..models.open_flow_value_failure_module_stop_after_if import OpenFlowValueFailureModuleStopAfterIf
     from ..models.open_flow_value_failure_module_suspend import OpenFlowValueFailureModuleSuspend
+    from ..models.open_flow_value_failure_module_timeout_type_0 import OpenFlowValueFailureModuleTimeoutType0
+    from ..models.open_flow_value_failure_module_timeout_type_1 import OpenFlowValueFailureModuleTimeoutType1
 
 
 T = TypeVar("T", bound="OpenFlowValueFailureModule")
@@ -32,7 +34,7 @@ class OpenFlowValueFailureModule:
         skip_if (Union[Unset, OpenFlowValueFailureModuleSkipIf]):
         sleep (Union['OpenFlowValueFailureModuleSleepType0', 'OpenFlowValueFailureModuleSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
-        timeout (Union[Unset, float]):
+        timeout (Union['OpenFlowValueFailureModuleTimeoutType0', 'OpenFlowValueFailureModuleTimeoutType1', Unset]):
         delete_after_use (Union[Unset, bool]):
         summary (Union[Unset, str]):
         mock (Union[Unset, OpenFlowValueFailureModuleMock]):
@@ -49,7 +51,7 @@ class OpenFlowValueFailureModule:
     skip_if: Union[Unset, "OpenFlowValueFailureModuleSkipIf"] = UNSET
     sleep: Union["OpenFlowValueFailureModuleSleepType0", "OpenFlowValueFailureModuleSleepType1", Unset] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
-    timeout: Union[Unset, float] = UNSET
+    timeout: Union["OpenFlowValueFailureModuleTimeoutType0", "OpenFlowValueFailureModuleTimeoutType1", Unset] = UNSET
     delete_after_use: Union[Unset, bool] = UNSET
     summary: Union[Unset, str] = UNSET
     mock: Union[Unset, "OpenFlowValueFailureModuleMock"] = UNSET
@@ -61,6 +63,7 @@ class OpenFlowValueFailureModule:
 
     def to_dict(self) -> Dict[str, Any]:
         from ..models.open_flow_value_failure_module_sleep_type_0 import OpenFlowValueFailureModuleSleepType0
+        from ..models.open_flow_value_failure_module_timeout_type_0 import OpenFlowValueFailureModuleTimeoutType0
 
         id = self.id
         value = self.value
@@ -91,7 +94,20 @@ class OpenFlowValueFailureModule:
                 sleep = self.sleep.to_dict()
 
         cache_ttl = self.cache_ttl
-        timeout = self.timeout
+        timeout: Union[Dict[str, Any], Unset]
+        if isinstance(self.timeout, Unset):
+            timeout = UNSET
+
+        elif isinstance(self.timeout, OpenFlowValueFailureModuleTimeoutType0):
+            timeout = UNSET
+            if not isinstance(self.timeout, Unset):
+                timeout = self.timeout.to_dict()
+
+        else:
+            timeout = UNSET
+            if not isinstance(self.timeout, Unset):
+                timeout = self.timeout.to_dict()
+
         delete_after_use = self.delete_after_use
         summary = self.summary
         mock: Union[Unset, Dict[str, Any]] = UNSET
@@ -157,6 +173,8 @@ class OpenFlowValueFailureModule:
         )
         from ..models.open_flow_value_failure_module_stop_after_if import OpenFlowValueFailureModuleStopAfterIf
         from ..models.open_flow_value_failure_module_suspend import OpenFlowValueFailureModuleSuspend
+        from ..models.open_flow_value_failure_module_timeout_type_0 import OpenFlowValueFailureModuleTimeoutType0
+        from ..models.open_flow_value_failure_module_timeout_type_1 import OpenFlowValueFailureModuleTimeoutType1
 
         d = src_dict.copy()
         id = d.pop("id")
@@ -217,7 +235,36 @@ class OpenFlowValueFailureModule:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
-        timeout = d.pop("timeout", UNSET)
+        def _parse_timeout(
+            data: object,
+        ) -> Union["OpenFlowValueFailureModuleTimeoutType0", "OpenFlowValueFailureModuleTimeoutType1", Unset]:
+            if isinstance(data, Unset):
+                return data
+            try:
+                if not isinstance(data, dict):
+                    raise TypeError()
+                _timeout_type_0 = data
+                timeout_type_0: Union[Unset, OpenFlowValueFailureModuleTimeoutType0]
+                if isinstance(_timeout_type_0, Unset):
+                    timeout_type_0 = UNSET
+                else:
+                    timeout_type_0 = OpenFlowValueFailureModuleTimeoutType0.from_dict(_timeout_type_0)
+
+                return timeout_type_0
+            except:  # noqa: E722
+                pass
+            if not isinstance(data, dict):
+                raise TypeError()
+            _timeout_type_1 = data
+            timeout_type_1: Union[Unset, OpenFlowValueFailureModuleTimeoutType1]
+            if isinstance(_timeout_type_1, Unset):
+                timeout_type_1 = UNSET
+            else:
+                timeout_type_1 = OpenFlowValueFailureModuleTimeoutType1.from_dict(_timeout_type_1)
+
+            return timeout_type_1
+
+        timeout = _parse_timeout(d.pop("timeout", UNSET))
 
         delete_after_use = d.pop("delete_after_use", UNSET)
 
