@@ -8,6 +8,7 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.open_flow_value_modules_item_retry_constant import OpenFlowValueModulesItemRetryConstant
     from ..models.open_flow_value_modules_item_retry_exponential import OpenFlowValueModulesItemRetryExponential
+    from ..models.open_flow_value_modules_item_retry_retry_if import OpenFlowValueModulesItemRetryRetryIf
 
 
 T = TypeVar("T", bound="OpenFlowValueModulesItemRetry")
@@ -19,10 +20,12 @@ class OpenFlowValueModulesItemRetry:
     Attributes:
         constant (Union[Unset, OpenFlowValueModulesItemRetryConstant]):
         exponential (Union[Unset, OpenFlowValueModulesItemRetryExponential]):
+        retry_if (Union[Unset, OpenFlowValueModulesItemRetryRetryIf]):
     """
 
     constant: Union[Unset, "OpenFlowValueModulesItemRetryConstant"] = UNSET
     exponential: Union[Unset, "OpenFlowValueModulesItemRetryExponential"] = UNSET
+    retry_if: Union[Unset, "OpenFlowValueModulesItemRetryRetryIf"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -34,6 +37,10 @@ class OpenFlowValueModulesItemRetry:
         if not isinstance(self.exponential, Unset):
             exponential = self.exponential.to_dict()
 
+        retry_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry_if, Unset):
+            retry_if = self.retry_if.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
@@ -41,6 +48,8 @@ class OpenFlowValueModulesItemRetry:
             field_dict["constant"] = constant
         if exponential is not UNSET:
             field_dict["exponential"] = exponential
+        if retry_if is not UNSET:
+            field_dict["retry_if"] = retry_if
 
         return field_dict
 
@@ -48,6 +57,7 @@ class OpenFlowValueModulesItemRetry:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.open_flow_value_modules_item_retry_constant import OpenFlowValueModulesItemRetryConstant
         from ..models.open_flow_value_modules_item_retry_exponential import OpenFlowValueModulesItemRetryExponential
+        from ..models.open_flow_value_modules_item_retry_retry_if import OpenFlowValueModulesItemRetryRetryIf
 
         d = src_dict.copy()
         _constant = d.pop("constant", UNSET)
@@ -64,9 +74,17 @@ class OpenFlowValueModulesItemRetry:
         else:
             exponential = OpenFlowValueModulesItemRetryExponential.from_dict(_exponential)
 
+        _retry_if = d.pop("retry_if", UNSET)
+        retry_if: Union[Unset, OpenFlowValueModulesItemRetryRetryIf]
+        if isinstance(_retry_if, Unset):
+            retry_if = UNSET
+        else:
+            retry_if = OpenFlowValueModulesItemRetryRetryIf.from_dict(_retry_if)
+
         open_flow_value_modules_item_retry = cls(
             constant=constant,
             exponential=exponential,
+            retry_if=retry_if,
         )
 
         open_flow_value_modules_item_retry.additional_properties = d
