@@ -15,6 +15,9 @@ if TYPE_CHECKING:
     from ..models.run_flow_preview_and_wait_result_json_body_value_modules_item import (
         RunFlowPreviewAndWaitResultJsonBodyValueModulesItem,
     )
+    from ..models.run_flow_preview_and_wait_result_json_body_value_notes_item import (
+        RunFlowPreviewAndWaitResultJsonBodyValueNotesItem,
+    )
     from ..models.run_flow_preview_and_wait_result_json_body_value_preprocessor_module import (
         RunFlowPreviewAndWaitResultJsonBodyValuePreprocessorModule,
     )
@@ -42,6 +45,8 @@ class RunFlowPreviewAndWaitResultJsonBodyValue:
         priority (Union[Unset, float]):
         early_return (Union[Unset, str]):
         chat_input_enabled (Union[Unset, bool]): Whether this flow accepts chat-style input
+        notes (Union[Unset, List['RunFlowPreviewAndWaitResultJsonBodyValueNotesItem']]): Sticky notes attached to the
+            flow
     """
 
     modules: List["RunFlowPreviewAndWaitResultJsonBodyValueModulesItem"]
@@ -59,6 +64,7 @@ class RunFlowPreviewAndWaitResultJsonBodyValue:
     priority: Union[Unset, float] = UNSET
     early_return: Union[Unset, str] = UNSET
     chat_input_enabled: Union[Unset, bool] = UNSET
+    notes: Union[Unset, List["RunFlowPreviewAndWaitResultJsonBodyValueNotesItem"]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -91,6 +97,13 @@ class RunFlowPreviewAndWaitResultJsonBodyValue:
         priority = self.priority
         early_return = self.early_return
         chat_input_enabled = self.chat_input_enabled
+        notes: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.notes, Unset):
+            notes = []
+            for notes_item_data in self.notes:
+                notes_item = notes_item_data.to_dict()
+
+                notes.append(notes_item)
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -127,6 +140,8 @@ class RunFlowPreviewAndWaitResultJsonBodyValue:
             field_dict["early_return"] = early_return
         if chat_input_enabled is not UNSET:
             field_dict["chat_input_enabled"] = chat_input_enabled
+        if notes is not UNSET:
+            field_dict["notes"] = notes
 
         return field_dict
 
@@ -141,6 +156,9 @@ class RunFlowPreviewAndWaitResultJsonBodyValue:
         from ..models.run_flow_preview_and_wait_result_json_body_value_modules_item import (
             RunFlowPreviewAndWaitResultJsonBodyValueModulesItem,
         )
+        from ..models.run_flow_preview_and_wait_result_json_body_value_notes_item import (
+            RunFlowPreviewAndWaitResultJsonBodyValueNotesItem,
+        )
         from ..models.run_flow_preview_and_wait_result_json_body_value_preprocessor_module import (
             RunFlowPreviewAndWaitResultJsonBodyValuePreprocessorModule,
         )
@@ -198,6 +216,13 @@ class RunFlowPreviewAndWaitResultJsonBodyValue:
 
         chat_input_enabled = d.pop("chat_input_enabled", UNSET)
 
+        notes = []
+        _notes = d.pop("notes", UNSET)
+        for notes_item_data in _notes or []:
+            notes_item = RunFlowPreviewAndWaitResultJsonBodyValueNotesItem.from_dict(notes_item_data)
+
+            notes.append(notes_item)
+
         run_flow_preview_and_wait_result_json_body_value = cls(
             modules=modules,
             failure_module=failure_module,
@@ -214,6 +239,7 @@ class RunFlowPreviewAndWaitResultJsonBodyValue:
             priority=priority,
             early_return=early_return,
             chat_input_enabled=chat_input_enabled,
+            notes=notes,
         )
 
         run_flow_preview_and_wait_result_json_body_value.additional_properties = d
