@@ -9,6 +9,7 @@ if TYPE_CHECKING:
     from ..models.run_flow_preview_json_body_value_failure_module import RunFlowPreviewJsonBodyValueFailureModule
     from ..models.run_flow_preview_json_body_value_flow_env import RunFlowPreviewJsonBodyValueFlowEnv
     from ..models.run_flow_preview_json_body_value_modules_item import RunFlowPreviewJsonBodyValueModulesItem
+    from ..models.run_flow_preview_json_body_value_notes_item import RunFlowPreviewJsonBodyValueNotesItem
     from ..models.run_flow_preview_json_body_value_preprocessor_module import (
         RunFlowPreviewJsonBodyValuePreprocessorModule,
     )
@@ -36,6 +37,7 @@ class RunFlowPreviewJsonBodyValue:
         priority (Union[Unset, float]):
         early_return (Union[Unset, str]):
         chat_input_enabled (Union[Unset, bool]): Whether this flow accepts chat-style input
+        notes (Union[Unset, List['RunFlowPreviewJsonBodyValueNotesItem']]): Sticky notes attached to the flow
     """
 
     modules: List["RunFlowPreviewJsonBodyValueModulesItem"]
@@ -53,6 +55,7 @@ class RunFlowPreviewJsonBodyValue:
     priority: Union[Unset, float] = UNSET
     early_return: Union[Unset, str] = UNSET
     chat_input_enabled: Union[Unset, bool] = UNSET
+    notes: Union[Unset, List["RunFlowPreviewJsonBodyValueNotesItem"]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -85,6 +88,13 @@ class RunFlowPreviewJsonBodyValue:
         priority = self.priority
         early_return = self.early_return
         chat_input_enabled = self.chat_input_enabled
+        notes: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.notes, Unset):
+            notes = []
+            for notes_item_data in self.notes:
+                notes_item = notes_item_data.to_dict()
+
+                notes.append(notes_item)
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -121,6 +131,8 @@ class RunFlowPreviewJsonBodyValue:
             field_dict["early_return"] = early_return
         if chat_input_enabled is not UNSET:
             field_dict["chat_input_enabled"] = chat_input_enabled
+        if notes is not UNSET:
+            field_dict["notes"] = notes
 
         return field_dict
 
@@ -129,6 +141,7 @@ class RunFlowPreviewJsonBodyValue:
         from ..models.run_flow_preview_json_body_value_failure_module import RunFlowPreviewJsonBodyValueFailureModule
         from ..models.run_flow_preview_json_body_value_flow_env import RunFlowPreviewJsonBodyValueFlowEnv
         from ..models.run_flow_preview_json_body_value_modules_item import RunFlowPreviewJsonBodyValueModulesItem
+        from ..models.run_flow_preview_json_body_value_notes_item import RunFlowPreviewJsonBodyValueNotesItem
         from ..models.run_flow_preview_json_body_value_preprocessor_module import (
             RunFlowPreviewJsonBodyValuePreprocessorModule,
         )
@@ -184,6 +197,13 @@ class RunFlowPreviewJsonBodyValue:
 
         chat_input_enabled = d.pop("chat_input_enabled", UNSET)
 
+        notes = []
+        _notes = d.pop("notes", UNSET)
+        for notes_item_data in _notes or []:
+            notes_item = RunFlowPreviewJsonBodyValueNotesItem.from_dict(notes_item_data)
+
+            notes.append(notes_item)
+
         run_flow_preview_json_body_value = cls(
             modules=modules,
             failure_module=failure_module,
@@ -200,6 +220,7 @@ class RunFlowPreviewJsonBodyValue:
             priority=priority,
             early_return=early_return,
             chat_input_enabled=chat_input_enabled,
+            notes=notes,
         )
 
         run_flow_preview_json_body_value.additional_properties = d
