@@ -32,6 +32,7 @@ class RunFlowPreviewJsonBodyValueModulesItemSuspend:
             'RunFlowPreviewJsonBodyValueModulesItemSuspendUserGroupsRequiredType1', Unset]):
         self_approval_disabled (Union[Unset, bool]):
         hide_cancel (Union[Unset, bool]):
+        continue_on_disapprove_timeout (Union[Unset, bool]):
     """
 
     required_events: Union[Unset, int] = UNSET
@@ -45,6 +46,7 @@ class RunFlowPreviewJsonBodyValueModulesItemSuspend:
     ] = UNSET
     self_approval_disabled: Union[Unset, bool] = UNSET
     hide_cancel: Union[Unset, bool] = UNSET
+    continue_on_disapprove_timeout: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -77,6 +79,7 @@ class RunFlowPreviewJsonBodyValueModulesItemSuspend:
 
         self_approval_disabled = self.self_approval_disabled
         hide_cancel = self.hide_cancel
+        continue_on_disapprove_timeout = self.continue_on_disapprove_timeout
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -95,6 +98,8 @@ class RunFlowPreviewJsonBodyValueModulesItemSuspend:
             field_dict["self_approval_disabled"] = self_approval_disabled
         if hide_cancel is not UNSET:
             field_dict["hide_cancel"] = hide_cancel
+        if continue_on_disapprove_timeout is not UNSET:
+            field_dict["continue_on_disapprove_timeout"] = continue_on_disapprove_timeout
 
         return field_dict
 
@@ -175,6 +180,8 @@ class RunFlowPreviewJsonBodyValueModulesItemSuspend:
 
         hide_cancel = d.pop("hide_cancel", UNSET)
 
+        continue_on_disapprove_timeout = d.pop("continue_on_disapprove_timeout", UNSET)
+
         run_flow_preview_json_body_value_modules_item_suspend = cls(
             required_events=required_events,
             timeout=timeout,
@@ -183,6 +190,7 @@ class RunFlowPreviewJsonBodyValueModulesItemSuspend:
             user_groups_required=user_groups_required,
             self_approval_disabled=self_approval_disabled,
             hide_cancel=hide_cancel,
+            continue_on_disapprove_timeout=continue_on_disapprove_timeout,
         )
 
         run_flow_preview_json_body_value_modules_item_suspend.additional_properties = d
